@@ -28,7 +28,9 @@ class GridItemTag(TaggedItemBase):
     """
 
     content_object = ParentalKey(
-        "GridItem", related_name="tagged_items", on_delete=models.CASCADE,
+        "GridItem",
+        related_name="tagged_items",
+        on_delete=models.CASCADE,
     )
 
 
@@ -125,15 +127,23 @@ class GridItem(Page):
 
     content_panels = Page.content_panels + [
         MultiFieldPanel(
-            CARD_PANELS, heading="Card Information", classname="collapsible",
+            CARD_PANELS,
+            heading="Card Information",
+            classname="collapsible",
         ),
         MultiFieldPanel(
             DETAIL_PANELS,
             heading="Expanded Description & Page Information",
             classname="collapsible",
         ),
-        StreamFieldPanel("buttons",),
-        MultiFieldPanel(META_PANELS, heading="Metadata", classname="collapsible",),
+        StreamFieldPanel(
+            "buttons",
+        ),
+        MultiFieldPanel(
+            META_PANELS,
+            heading="Metadata",
+            classname="collapsible",
+        ),
     ]
 
     def save(self, *args, **kwargs):
@@ -162,11 +172,15 @@ class GridIndexGridItemRelationship(Orderable, models.Model):
     panels = [PageChooserPanel("grid_item")]
 
 
-class GridIndexPage(Page):
+class GridIndexPageAbstract(models.Model):
     """
     Index page for Grid Items.
     This links the grid items to the categories and provides a page to display them on.
+
+    This abstract class exists to allow compositing the index page with other page
+    functionality by future users. GridIndexPage below makes this concrete.
     """
+
     subpage_types = get_grid_index_page_subpage_types()
 
     hero_background_image = models.ForeignKey(
@@ -218,7 +232,7 @@ class GridIndexPage(Page):
     )
 
     featured_grid_item_1 = models.ForeignKey(
-        "GridItem",
+        GridItem,
         null=True,
         blank=True,
         on_delete=models.SET_NULL,
@@ -228,7 +242,7 @@ class GridIndexPage(Page):
     )
 
     featured_grid_item_2 = models.ForeignKey(
-        "GridItem",
+        GridItem,
         null=True,
         blank=True,
         on_delete=models.SET_NULL,
@@ -248,8 +262,12 @@ class GridIndexPage(Page):
             GridIndexGridItemRelationship.objects.values_list(
                 "grid_item__categories__name"
             )
-            .filter(grid_relationship__id=self.id,)
-            .order_by("grid_item__categories__name",)
+            .filter(
+                grid_relationship__id=self.id,
+            )
+            .order_by(
+                "grid_item__categories__name",
+            )
             .distinct()
         )
 
@@ -268,8 +286,8 @@ class GridIndexPage(Page):
         FieldPanel("hero_button_text"),
         FieldPanel("hero_button_url"),
         FieldPanel("featured_description"),
-        PageChooserPanel("featured_grid_item_1"),
-        PageChooserPanel("featured_grid_item_2"),
+        PageChooserPanel("featured_grid_item_1", GridItem),
+        PageChooserPanel("featured_grid_item_2", GridItem),
     ]
 
     content_panels = Page.content_panels + [
@@ -291,7 +309,18 @@ class GridIndexPage(Page):
     ]
 
     class Meta:
-        verbose_name = "Grid Index Page"
+        abstract = True
 
     def __str__(self):
-        return "{0}".format(self.grid_items,)
+        return "{0}".format(
+            self.grid_items,
+        )
+
+
+class GridIndexPage(Page, GridIndexPageAbstract):
+    """
+    Concrete implementation of GridIndexPageAbstract.
+    """
+
+    class Meta:
+        verbose_name = "Grid Index Page"
